==> regina-normal_7.4.orig.tar.gz: regina-7.4/qtui/src/graphviz.h <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Qt User Interface                                                     *
 *                                                                        *
 *  Copyright (c) 1999-2025, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public License     *
 *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
 *                                                                        *
 **************************************************************************/

/*! \file graphviz.h
 *  \brief Provides the glue between Regina and Graphviz.
 */

#ifndef __GRAPHVIZ_H
#define __GRAPHVIZ_H

#include "regina-config.h" // for LIBGVC_FOUND
#include <string>

class QSvgWidget;

class Graphviz {
    public:
#ifdef LIBGVC_FOUND
        enum class Renderer { Neato, Dot };

        static void render(QSvgWidget* widget, const std::string& dot,
            Renderer renderer);
#else
        static const char* notSupported;
#endif
};

#endif

==> regina-normal_7.4.1.orig.tar.gz: regina-7.4.1/qtui/src/graphviz.h <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Qt User Interface                                                     *
 *                                                                        *
 *  Copyright (c) 1999-2025, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public License     *
 *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
 *                                                                        *
 **************************************************************************/

/*! \file graphviz.h
 *  \brief Provides the glue between Regina and Graphviz.
 */

#ifndef __GRAPHVIZ_H
#define __GRAPHVIZ_H

#include "regina-config.h" // for LIBGVC_FOUND and LIBGVC_DYNAMIC_PLUGINS
#include <string>

class QSvgWidget;

class Graphviz {
    public:
#ifdef LIBGVC_FOUND
        enum class Renderer { Neato, Dot };

        static void render(QSvgWidget* widget, const std::string& dot,
            Renderer renderer);
#else
        static const char* notSupported;
#endif
};

#endif
